@@ -1,49 +1,60 @@
 /***********************************************************************
-* SPDX-FileCopyrightText: 2003-2004 Max Howell <max.howell@methylblue.com>
-* SPDX-FileCopyrightText: 2008-2009 Martin Sandsmark <martin.sandsmark@kde.org>
-* SPDX-FileCopyrightText: 2017 Harald Sitter <sitter@kde.org>
-*
-* SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
-***********************************************************************/
+ * SPDX-FileCopyrightText: 2003-2004 Max Howell <max.howell@methylblue.com>
+ * SPDX-FileCopyrightText: 2008-2009 Martin Sandsmark <martin.sandsmark@kde.org>
+ * SPDX-FileCopyrightText: 2017-2022 Harald Sitter <sitter@kde.org>
+ *
+ * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
+ ***********************************************************************/
 
-#ifndef FILETREE_H
-#define FILETREE_H
+#pragma once
+
+#include <cstdlib>
 
-#include <QByteArray> //qstrdup
 #include <KFormat>
 
-#include <stdlib.h>
+#include <QByteArray> //qstrdup
 
-typedef quint64 FileSize;
-typedef quint64 Dirsize;  //**** currently unused
+using FileSize = quint64;
+using DirSize = quint64; //**** currently unused
 
 class Folder;
 
-class File
+class File : public QObject
 {
 public:
     friend class Folder;
+    Q_OBJECT
 
 public:
-    File(const char *name, FileSize size) : m_parent(nullptr), m_name(qstrdup(name)), m_size(size) {}
-    virtual ~File() {
-        delete [] m_name;
+    File(const char *name, FileSize size)
+        : m_parent(nullptr)
+        , m_name(qstrdup(name))
+        , m_size(size)
+    {
+    }
+    ~File() override
+    {
+        delete[] m_name;
     }
 
-    Folder *parent() const {
+    Folder *parent() const
+    {
         return m_parent;
     }
 
     /** Do not use for user visible strings. Use name instead. */
-    const char *name8Bit() const {
+    const char *name8Bit() const
+    {
         return m_name;
     }
-    void setName(const QByteArray &newName) {
-        delete [] m_name;
+    void setName(const QByteArray &newName)
+    {
+        delete[] m_name;
         m_name = qstrdup(newName.constData());
     }
     /** Decoded name. Use when you need a QString. */
-    QString decodedName() const {
+    QString decodedName() const
+    {
         return QString::fromUtf8(m_name);
     }
     /**
@@ -52,11 +63,13 @@ public:
      */
     QString displayName() const;
 
-    FileSize size() const {
+    FileSize size() const
+    {
         return m_size;
     }
 
-    virtual bool isFolder() const {
+    virtual bool isFolder() const
+    {
         return false;
     }
 
@@ -65,7 +78,8 @@ public:
      * Only use for display.
      */
     QString displayPath(const Folder * = nullptr) const;
-    QString humanReadableSize() const {
+    QString humanReadableSize() const
+    {
         return KFormat().formatByteSize(m_size);
     }
 
@@ -73,41 +87,51 @@ public:
     QUrl url(const Folder *root = nullptr) const;
 
 protected:
-    File(const char *name, FileSize size, Folder *parent) : m_parent(parent), m_name(qstrdup(name)), m_size(size) {}
+    File(const char *name, FileSize size, Folder *parent)
+        : m_parent(parent)
+        , m_name(qstrdup(name))
+        , m_size(size)
+    {
+    }
 
-    Folder *m_parent; //0 if this is treeRoot
+    Folder *m_parent; // 0 if this is treeRoot
     char *m_name; // partial path name (e.g. 'boot/' or 'foo.svg')
     FileSize m_size; // in units of bytes; sum of all children's sizes
 
 private:
-    File(const File&);
-    void operator=(const File&);
+    Q_DISABLE_COPY_MOVE(File)
 };
 
-
 class Folder : public File
 {
+    Q_OBJECT
+    Q_PROPERTY(uint children MEMBER m_children CONSTANT)
 public:
-    Folder(const char *name) : File(name, 0), m_children(0) {} //DON'T pass the full path!
+    explicit Folder(const char *name)
+        : File(name, 0)
+    {
+    } // DON'T pass the full path!
 
     ~Folder() override
     {
         qDeleteAll(files);
     }
 
-    uint children() const {
+    uint children() const
+    {
         return m_children;
     }
-    bool isFolder() const override {
+    bool isFolder() const override
+    {
         return true;
     }
 
     Folder *duplicate() const
     {
-        Folder *ret = new Folder(m_name);
+        auto ret = new Folder(m_name);
         for (const File *child : files) {
             if (child->isFolder()) {
-                ret->append(((Folder*)child)->duplicate());
+                ret->append(((Folder *)child)->duplicate());
             } else {
                 ret->append(child->name8Bit(), child->size());
             }
@@ -115,28 +139,29 @@ public:
         return ret;
     }
 
-    ///appends a Folder
-    void append(Folder *d, const char *name=nullptr)
+    /// appends a Folder
+    void append(Folder *d, const char *name = nullptr)
     {
         if (name) {
-            delete [] d->m_name;
+            delete[] d->m_name;
             d->m_name = qstrdup(name);
-        } //directories that had a fullpath copy just their names this way
+        } // directories that had a fullpath copy just their names this way
 
-        m_children += d->children(); //doesn't include the dir itself
+        m_children += d->children(); // doesn't include the dir itself
         d->m_parent = this;
-        append((File*)d); //will add 1 to filecount for the dir itself
+        append((File *)d); // will add 1 to filecount for the dir itself
     }
 
-    ///appends a File
+    /// appends a File
     void append(const char *name, FileSize size)
     {
         append(new File(name, size, this));
     }
 
     /// removes a file
-    void remove(const File *f) {
-        files.removeAll(const_cast<File*>(f));
+    void remove(const File *f)
+    {
+        files.removeAll(const_cast<File *>(f));
         const FileSize childSize = f->size();
         delete f;
 
@@ -147,8 +172,9 @@ public:
     }
 
     // Removes a file, but does not delete
-    const File *take(const File *f) {
-        files.removeAll(const_cast<File*>(f));
+    const File *take(const File *f)
+    {
+        files.removeAll(const_cast<File *>(f));
         const FileSize childSize = f->size();
 
         for (Folder *d = this; d; d = d->parent()) {
@@ -172,11 +198,8 @@ private:
         files.append(p);
     }
 
-    uint m_children;
+    uint m_children = 0;
 
 private:
-    Folder(const Folder&); //undefined
-    void operator=(const Folder&); //undefined
+    Q_DISABLE_COPY_MOVE(Folder)
 };
-
-#endif
